@@ -21,11 +21,12 @@
 #include "quicklaunchplugin.h"
 #include "quicklaunch_p.h"
 
-#include <QtQml>
+// Qt
+#include <QQmlEngine>
 
 void QuicklaunchPlugin::registerTypes(const char *uri)
 {
-    Q_ASSERT(uri == QLatin1String("org.kde.plasma.private.quicklaunch"));
+    Q_ASSERT(QLatin1String(uri) == QLatin1String("org.kde.plasma.private.quicklaunch"));
 
     qmlRegisterType<QuicklaunchPrivate>(uri, 1, 0, "Logic");
 }
