@@ -19,20 +19,26 @@
 
 #include "potd.h"
 
-#include <QtCore/QDate>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
-#include <QtCore/QTimer>
-#include <QtCore/QThreadPool>
-
+#include <QDate>
+#include <QFile>
+#include <QFileInfo>
+#include <QTimer>
+#include <QThreadPool>
 #include <QDebug>
+
 #include <KPluginLoader>
 #include <KPluginMetaData>
-
 #include <Plasma/DataContainer>
 
 #include "cachedprovider.h"
 
+namespace {
+namespace DataKeys {
+inline QString image() { return QStringLiteral("Image"); }
+inline QString url()   { return QStringLiteral("Url"); }
+}
+}
+
 PotdEngine::PotdEngine( QObject* parent, const QVariantList& args )
     : Plasma::DataEngine( parent, args )
 {
@@ -126,7 +132,7 @@ bool PotdEngine::updateSource( const QString &identifier, bool loadCachedAlways
 bool PotdEngine::sourceRequestEvent( const QString &identifier )
 {
     if ( updateSource( identifier, true ) ) {
-        setData( identifier, "Image", QImage() );
+        setData(identifier, DataKeys::image(), QImage());
         return true;
     }
 
@@ -137,7 +143,7 @@ void PotdEngine::finished( PotdProvider *provider )
 {
     if ( m_canDiscardCache && qobject_cast<CachedProvider *>( provider ) ) {
         Plasma::DataContainer *source = containerForSource( provider->identifier() );
-        if ( source && !source->data().value( "Image" ).value<QImage>().isNull() ) {
+        if ( source && !source->data().value(DataKeys::image()).value<QImage>().isNull() ) {
             provider->deleteLater();
             return;
         }
@@ -145,13 +151,13 @@ void PotdEngine::finished( PotdProvider *provider )
 
     QImage img(provider->image());
     // store in cache if it's not the response of a CachedProvider
-    if ( qobject_cast<CachedProvider*>( provider ) == 0 && !img.isNull() ) {
+    if ( qobject_cast<CachedProvider*>( provider ) == nullptr && !img.isNull() ) {
         SaveImageThread *thread = new SaveImageThread( provider->identifier(), img );
         connect(thread, SIGNAL(done(QString,QString,QImage)), this, SLOT(cachingFinished(QString,QString,QImage)));
         QThreadPool::globalInstance()->start(thread);
     } else {
-        setData( provider->identifier(), "Image", img );
-        setData( provider->identifier(), "Url", CachedProvider::identifierToPath( provider->identifier()) );
+        setData(provider->identifier(), DataKeys::image(), img);
+        setData(provider->identifier(), DataKeys::url(), CachedProvider::identifierToPath( provider->identifier()));
     }
 
     provider->deleteLater();
@@ -159,8 +165,8 @@ void PotdEngine::finished( PotdProvider *provider )
 
 void PotdEngine::cachingFinished( const QString &source, const QString &path, const QImage &img )
 {
-    setData( source, "Image", img );
-    setData( source, "Url", path );
+    setData(source, DataKeys::image(), img);
+    setData(source, DataKeys::url(), path);
 }
 
 void PotdEngine::error( PotdProvider *provider )
@@ -176,17 +182,17 @@ void PotdEngine::checkDayChanged()
     while ( it.hasNext() ) {
         it.next();
 
-        if ( it.key() == "Providers" ) {
+        if (it.key() == QLatin1String("Providers")) {
             continue;
         }
 
-        if ( !it.key().contains(':') ) {
+        if ( !it.key().contains(QLatin1Char(':')) ) {
             const QString path = CachedProvider::identifierToPath( it.key() );
             if ( !QFile::exists(path) ) {
                 updateSourceEvent( it.key() );
             } else {
                 QFileInfo info( path );
-                if ( info.lastModified().daysTo( QDateTime::currentDateTime() ) >= 1 ) {
+                if ( info.lastModified().daysTo( QDateTime::currentDateTime() ) > 1 ) {
                     updateSourceEvent( it.key() );
                 }
             }
